[Xfce4-commits] [xfce/thunar] 01/01: Add missing top border to side pane

noreply at xfce.org noreply at xfce.org
Tue Aug 21 03:41:06 CEST 2018


This is an automated email from the git hooks/post-receive script.

a   n   d   r   e       p   u   s   h   e   d       a       c   o   m   m   i   t       t   o       b   r   a   n   c   h       x   f   c   e   -   4   .   1   4   
   in repository xfce/thunar.

commit 5a1803a9147f6f4dfc6a644ac037920dee01ebe4
Author: Andre Miranda <andreldm at xfce.org>
Date:   Mon Aug 20 22:39:37 2018 -0300

    Add missing top border to side pane
---
 thunar/thunar-application.c | 18 ++++++++++--------
 1 file changed, 10 insertions(+), 8 deletions(-)

diff --git a/thunar/thunar-application.c b/thunar/thunar-application.c
index 604d8a4..957c598 100644
--- a/thunar/thunar-application.c
+++ b/thunar/thunar-application.c
@@ -581,14 +581,16 @@ thunar_application_load_css (void)
 
   css_provider = gtk_css_provider_new ();
 
-                                                 /* For the pathbar-buttons any margin looks ugly*/
-  gtk_css_provider_load_from_data (css_provider, ".path-bar-button { margin-right: 0; }"
-
-                                                 /* remove extra border between side pane and view */
-                                                 /* also make border thicker during DnD */
-                                                 ".shortcuts-pane { border-right-width: 0px; }"
-                                                 ".standard-view { border-left-width: 0px; }"
-                                                 ".standard-view:drop(active) { border-width: 2px; }", -1, NULL);
+  gtk_css_provider_load_from_data (css_provider,
+    /* for the pathbar-buttons any margin looks ugly*/
+    ".path-bar-button { margin-right: 0; }"
+    /* remove extra border between side pane and view */
+    ".shortcuts-pane { border-right-width: 0px; }"
+    /* add missing top border to side pane */
+    ".shortcuts-pane { border-top-style: solid; }"
+    /* make border thicker during DnD */
+    ".standard-view { border-left-width: 0px; }"
+    ".standard-view:drop(active) { border-width: 2px; }", -1, NULL);
   screen = gdk_screen_get_default ();
   gtk_style_context_add_provider_for_screen (screen, GTK_STYLE_PROVIDER (css_provider), GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
   g_object_unref (css_provider);

-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the Xfce4-commits mailing list